@@ -1,5 +1,3 @@
-{-# LANGUAGE CPP #-}
---------------------------------------------------------------------
 -- |
 -- Module    : Text.JSON.Parsec
 -- Copyright : (c) Galois, Inc. 2007-2009, Duncan Coutts 2015
@@ -30,28 +28,21 @@ module Text.JSON.Canonical
   , prettyCanonicalJSON
   ) where
 
-import MyPrelude
+import Prelude
 import Text.ParserCombinators.Parsec
          ( CharParser, (<|>), (<?>), many, between, sepBy
          , satisfy, char, string, digit, spaces
          , parse )
 import Text.PrettyPrint hiding (char)
 import qualified Text.PrettyPrint as Doc
-#if !(MIN_VERSION_base(4,7,0))
-import Control.Applicative ((<$>), (<$), pure, (<*>), (<*), (*>))
-#endif
 import Control.Arrow (first)
-import Data.Bits (Bits)
-#if MIN_VERSION_base(4,7,0)
-import Data.Bits (FiniteBits)
-#endif
+import Data.Bits (Bits, FiniteBits)
 import Data.Char (isDigit, digitToInt)
 import Data.Data (Data)
 import Data.Function (on)
 import Data.Int (Int64)
 import Data.Ix (Ix)
 import Data.List (foldl', sortBy)
-import Data.Typeable (Typeable)
 import Foreign.Storable (Storable)
 import Text.Printf (PrintfArg)
 import qualified Data.ByteString.Lazy.Char8 as BS
@@ -83,13 +74,10 @@ newtype Int54 = Int54 { int54ToInt64 :: Int64 }
            , Ord
            , Real
            , Ix
-#if MIN_VERSION_base(4,7,0)
            , FiniteBits
-#endif
            , Bits
            , Storable
            , PrintfArg
-           , Typeable
            )
 
 instance Bounded Int54 where
@@ -353,4 +341,3 @@ punctuate' l p r (x:xs) = l <+> x : go xs
     go []     = []
     go [y]    = [p <+> y, r]
     go (y:ys) = (p <+> y) : go ys
-
