@@ -2,14 +2,14 @@
 module Main (main) where
 
 -- stdlib
-import Control.Exception
-import Control.Monad
+import Control.Exception ( handleJust )
+import Control.Monad ( unless )
 import Data.Maybe (fromJust)
-import Data.Time
-import Network.URI (URI, parseURI)
-import Test.Tasty
-import Test.Tasty.HUnit
-import Test.Tasty.QuickCheck hiding (label)
+import Data.Time ( UTCTime, getCurrentTime )
+import Network.URI ( URI, parseURI )
+import Test.Tasty ( defaultMain, testGroup, TestTree )
+import Test.Tasty.HUnit ( testCase, (@?=), assertEqual, assertFailure, Assertion )
+import Test.Tasty.QuickCheck ( testProperty )
 import System.IO.Temp (withSystemTempDirectory)
 import qualified Codec.Archive.Tar.Entry    as Tar
 import qualified Data.ByteString.Lazy.Char8 as BS
@@ -238,7 +238,7 @@ testRepoIndex inMemRepo repo = do
     length (directoryEntries dir1) @?= 0
 
     now <- getCurrentTime
-    inMemRepoSetIndex inMemRepo now [testEntry1]
+    inMemRepoSetIndex inMemRepo now testEntries1
 
     assertEqual "B" HasUpdates =<< checkForUpdates repo =<< checkExpiry
     dir2 <- getDirectory repo
@@ -264,9 +264,16 @@ testRepoIndex inMemRepo repo = do
              _        -> fail "unexpected index entry content"
          _ -> fail "unexpected index path"
 
-    testEntry1 = Tar.fileEntry path testEntrycontent
-      where
-        Right path = Tar.toTarPath False "foo/preferred-versions"
+
+#if MIN_VERSION_tar(0,7,0)
+    testEntries1 :: [Tar.GenEntry BS.ByteString Tar.TarPath linkTarget]
+#elif MIN_VERSION_tar(0,6,0)
+    testEntries1 :: [Tar.GenEntry Tar.TarPath linkTarget]
+#else
+    testEntries1 :: [Tar.Entry]
+#endif
+    testEntries1 = either (const []) (pure . (`Tar.fileEntry` testEntrycontent))
+        (Tar.toTarPath False "foo/preferred-versions")
     testEntrycontent   = BS.pack "foo >= 1"
     testEntryIndexFile = IndexPkgPrefs (mkPackageName "foo")
 
